==> parcel-bundler-vue-1.6.3.tgz: package/lib/assets/JSONAsset.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Asset = require('../Asset');
var path = require('path');
var json5 = require('json5');

var _require = require('uglify-es'),
    minify = _require.minify;

var JSONAsset = function (_Asset) {
  (0, _inherits3.default)(JSONAsset, _Asset);

  function JSONAsset(name, pkg, options) {
    (0, _classCallCheck3.default)(this, JSONAsset);

    var _this = (0, _possibleConstructorReturn3.default)(this, (JSONAsset.__proto__ || (0, _getPrototypeOf2.default)(JSONAsset)).call(this, name, pkg, options));

    _this.type = 'js';
    return _this;
  }

  (0, _createClass3.default)(JSONAsset, [{
    key: 'parse',
    value: function parse(code) {
      return path.extname(this.name) === '.json5' ? json5.parse(code) : null;
    }
  }, {
    key: 'generate',
    value: function generate() {
      var code = 'module.exports = ' + (this.ast ? (0, _stringify2.default)(this.ast, null, 2) : this.contents) + ';';

      if (this.options.minify) {
        var minified = minify(code);
        if (minified.error) {
          throw minified.error;
        }

        code = minified.code;
      }

      return {
        js: code
      };
    }
  }]);
  return JSONAsset;
}(Asset);

module.exports = JSONAsset;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/assets/JSONAsset.js <==
'use strict';

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Asset = require('../Asset');

var _require = require('uglify-es'),
    minify = _require.minify;

var JSONAsset = function (_Asset) {
  (0, _inherits3.default)(JSONAsset, _Asset);

  function JSONAsset(name, pkg, options) {
    (0, _classCallCheck3.default)(this, JSONAsset);

    var _this = (0, _possibleConstructorReturn3.default)(this, (JSONAsset.__proto__ || (0, _getPrototypeOf2.default)(JSONAsset)).call(this, name, pkg, options));

    _this.type = 'js';
    return _this;
  }

  (0, _createClass3.default)(JSONAsset, [{
    key: 'generate',
    value: function generate() {
      var code = 'module.exports = ' + this.contents + ';';

      if (this.options.minify) {
        var minified = minify(code);
        if (minified.error) {
          throw minified.error;
        }

        code = minified.code;
      }

      return {
        js: code
      };
    }
  }]);
  return JSONAsset;
}(Asset);

module.exports = JSONAsset;
